[zorg] r181261 - Add a second run of the libcxx scripts which uses the newly built dylib instead of the system's dylib.

David Dean david_dean at apple.com
Mon May 6 15:44:36 PDT 2013


Author: ddean
Date: Mon May  6 17:44:36 2013
New Revision: 181261

URL: http://llvm.org/viewvc/llvm-project?rev=181261&view=rev
Log:
Add a second run of the libcxx scripts which uses the newly built dylib instead of the system's dylib.

Modified:
    zorg/trunk/zorg/buildbot/builders/LNTBuilder.py
    zorg/trunk/zorg/buildbot/builders/LibCXXBuilder.py

Modified: zorg/trunk/zorg/buildbot/builders/LNTBuilder.py
URL: http://llvm.org/viewvc/llvm-project/zorg/trunk/zorg/buildbot/builders/LNTBuilder.py?rev=181261&r1=181260&r2=181261&view=diff
==============================================================================
--- zorg/trunk/zorg/buildbot/builders/LNTBuilder.py (original)
+++ zorg/trunk/zorg/buildbot/builders/LNTBuilder.py Mon May  6 17:44:36 2013
@@ -5,6 +5,7 @@ Builders for using LNT to test LLVM/Clan
 import os
 
 import buildbot
+from buildbot.process.properties import Interpolate
 from buildbot.steps.source.svn import SVN
 from buildbot.process.properties import WithProperties
 
@@ -65,17 +66,18 @@ def AddLNTTestsToFactory(f, nt_flags, cc
         nt_flags.extend(['--liblto-path', WithProperties(
                          os.path.join('%(builddir)s', base_directory, 'lib',
                                       'libLTO.dylib'))])
+    llvm_base_url = 'http://llvm.org/svn/llvm-project/'
+    # Get the LLVM test-suite sources.
+    testsuite_url = llvm_base_url + 'test-suite/%(src::branch:-trunk)s'
+    f.addStep(SVN(name='pull.test-suite', mode='incremental', method='fresh',
+                  repourl=Interpolate(testsuite_url),
+                  workdir='test-suite', alwaysUseLatest=False))
 
     # Get the LNT sources.
+    lnt_url = llvm_base_url + 'lnt/%(src::branch:-trunk)s'
     f.addStep(SVN(name='pull.lnt', mode='incremental', method='fresh',
-                  baseURL='http://llvm.org/svn/llvm-project/lnt/',
-                  defaultBranch='trunk', workdir='lnt', alwaysUseLatest=True))
-
-    # Get the LLVM test-suite sources.
-    f.addStep(SVN(name='pull.test-suite', mode='incremental', method='fresh',
-                  baseURL='http://llvm.org/svn/llvm-project/test-suite/',
-                  defaultBranch='trunk', workdir='test-suite',
-                  alwaysUseLatest=False))
+                  repourl=Interpolate(lnt_url),
+                  workdir='lnt', alwaysUseLatest=True))
 
     # Create the LNT virtual env.
     f.addStep(buildbot.steps.shell.ShellCommand(

Modified: zorg/trunk/zorg/buildbot/builders/LibCXXBuilder.py
URL: http://llvm.org/viewvc/llvm-project/zorg/trunk/zorg/buildbot/builders/LibCXXBuilder.py?rev=181261&r1=181260&r2=181261&view=diff
==============================================================================
--- zorg/trunk/zorg/buildbot/builders/LibCXXBuilder.py (original)
+++ zorg/trunk/zorg/buildbot/builders/LibCXXBuilder.py Mon May  6 17:44:36 2013
@@ -49,9 +49,9 @@ def getLibCXXBuilder():
             command=['lit.venv/bin/pip', 'install', 'lit'],
             workdir='.', haltOnFailure=True))
 
     # Run the tests.
     f.addStep(zorg.buildbot.commands.LitTestCommand.LitTestCommand(
-            name='test.libcxx',
+            name='test.libcxx.system',
             command=[
                 properties.WithProperties('%(builddir)s/lit.venv/bin/lit'),
                 '-v',
@@ -60,5 +60,16 @@ def getLibCXXBuilder():
                 '--param=use_system_lib=true',
                 'sources/test'],
             workdir='.'))
+    # Run the tests with the newly built dylib
+    f.addStep(zorg.buildbot.commands.LitTestCommand.LitTestCommand(
+            name='test.libcxx.new',
+            command=[
+                properties.WithProperties('%(builddir)s/lit.venv/bin/lit'),
+                '-v',
+                properties.WithProperties(
+                    '--param=cxx_under_test=%s' % (cxx_path,)),
+                '--param=use_system_lib=false',
+                'sources/test'],
+            workdir='.'))
 
     return f
@@ -49,9 +49,9 @@ def getLibCXXBuilder():
             workdir='.', haltOnFailure=True))
 
-    # Run the tests.
+    # Run the tests with the system's dylib
     f.addStep(zorg.buildbot.commands.LitTestCommand.LitTestCommand(





More information about the llvm-commits mailing list